#  tests for setuptools_scm_git_archive-1.0-py27_1 (this is a generated file);
print('===== testing package: setuptools_scm_git_archive-1.0-py27_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
from pkg_resources import load_entry_point

ENTRY_GROUP = 'setuptools_scm.parse_scm'
ENTRY_NAME = '.git_archival.txt'

dist = 'setuptools_scm_git_archive'
load_entry_point(dist, ENTRY_GROUP, ENTRY_NAME)
#  --- run_test.py (end) ---

print('===== setuptools_scm_git_archive-1.0-py27_1 OK =====');
print("import: 'setuptools_scm_git_archive'")
import setuptools_scm_git_archive

